@@ -1,12 +1,12 @@
-#ifndef BREEZE_BUTTONS_H
-#define BREEZE_BUTTONS_H
-
 /*
  * SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
  * SPDX-FileCopyrightText: 2014 Hugo Pereira Da Costa <hugo.pereira@free.fr>
  *
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
+
+#pragma once
+
 #include "breezedecoration.h"
 #include <KDecoration2/DecorationButton>
 
@@ -133,5 +133,3 @@ private:
 };
 
 } // namespace
-
-#endif
