@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef breeze_helper_h
-#define breeze_helper_h
+#pragma once
 
 #include "breeze.h"
 #include "breezeanimationdata.h"
@@ -22,6 +21,9 @@
 #include <QToolBar>
 #include <QWidget>
 
+class QSlider;
+class QStyleOptionSlider;
+
 namespace Breeze
 {
 //* breeze style helper class.
@@ -259,6 +261,12 @@ public:
     //* slider groove
     void renderSliderGroove(QPainter *, const QRect &, const QColor &) const;
 
+    //* reimplementation of protected method
+    void initSliderStyleOption(const QSlider *, QStyleOptionSlider *) const;
+
+    //* slider focus frame
+    QRectF pathForSliderHandleFocusFrame(QPainterPath &, const QRect &, int hmargin, int vmargin) const;
+
     //* slider handle
     void renderSliderHandle(QPainter *, const QRect &, const QColor &, const QColor &outline, const QColor &shadow, bool sunken) const;
 
@@ -348,7 +356,12 @@ public:
         return rect.adjusted(shadowSize, shadowSize, -shadowSize, -shadowSize);
     }
 
-    QPixmap coloredIcon(const QIcon &icon, const QPalette &palette, const QSize &size, QIcon::Mode mode = QIcon::Normal, QIcon::State state = QIcon::Off);
+    QPixmap coloredIcon(const QIcon &icon,
+                        const QPalette &palette,
+                        const QSize &size,
+                        qreal devicePixelRatio,
+                        QIcon::Mode mode = QIcon::Normal,
+                        QIcon::State state = QIcon::Off);
 
 protected:
     //* return rounded path in a given rect, with only selected corners rounded, and for a given radius
@@ -388,5 +401,3 @@ private:
 };
 
 }
-
-#endif
