@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef breezepropertynames_h
-#define breezepropertynames_h
+#pragma once
 
 namespace Breeze
 {
@@ -21,8 +20,7 @@ struct PropertyNames {
     static const char noSeparator[];
     static const char isTopMenu[];
     static const char bordersSides[];
+    static const char forceFrame[];
 };
 
 }
-
-#endif
